@@ -5,6 +5,7 @@ import paraselene.supervisor.*;
 import paraselene.ajax.*;
 import java.io.*;
 import javax.servlet.http.*;
+import paraselene.dyna.*;
 
 /**
  * JSON非同期通信。
@@ -158,5 +159,6 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 			throw new PageException( e );
 		}
 	}
+	public NameDefine[] inspectName( Page page, String ... exclude ){ return null;}
 }
 
