@@ -13,10 +13,10 @@ import java.io.*;
 public class Exec implements Serializable {
 	private static final long serialVersionUID = 2L;
 
-	public String	cmd = "";
+	public String[]	cmd = null;
 
 	private Exec(){}
-	public Exec( String c ) {
+	public Exec( String ... c ) {
 		cmd = c;
 	}
 }
