@@ -20,14 +20,21 @@ public class TagData implements Serializable {
 
 	TagData(){}
 	TagData( Tag tag ) {
+		this( tag, true );
+	}
+	TagData( Tag tag, boolean flag ) {
 		this.id = tag.getAttributeToString( "id" );
-		int cnt = tag.getHTMLPartCount();
-		JsonWriter	w = new JsonWriter();
-		for ( int i = 0; i < cnt; i++ ) {
-			tag.getHTMLPart( i ).write( w, HTMLPart.StringMode.BODY );
+		Page	page = tag.getAssignedPage();
+		if ( flag ) {
+			int cnt = tag.getHTMLPartCount();
+			JsonWriter	w = new JsonWriter();
+			for ( int i = 0; i < cnt; i++ ) {
+				tag.getHTMLPart( i ).write( w, HTMLPart.StringMode.BODY );
+			}
+			body = w.toString();
+			cmd = new String[]{ page.getOnLoadScript() };
 		}
-		body = w.toString();
-		cmd = w.getScript();
+		page.resetOnLoadScript();
 	}
 
 	public static TagData[] getTag( Page p ) {
