@@ -68,8 +68,16 @@ class OutputCall {
 	}
 
 	PostBack[] make() throws Exception {
-		data.hist.get( next_key ).add( next_page );
-		TagData[]	data = TagData.getTag( out[1] );
+		History	h = data.hist.get( next_key );
+		h.add( next_page );
+		TagData[]	data = null;
+		try{
+			h.lock();
+			data = TagData.getTag( out[1] );
+		}
+		finally{
+			h.unlock();
+		}
 		PostBack[]	ret = new PostBack[data.length];
 		for ( int i = 0; i < ret.length; i++ ) {
 			ret[i] = new PostBack( data[i] );
@@ -93,26 +101,33 @@ class OpenOutput extends OutputCall {
 
 	PostBack[] make() throws Exception {
 		Popup	p = (Popup)forward;
+		History	h = data.hist.get( next_key );
 		if ( p.active_page == null ) {
-			data.hist.get( next_key ).add( next_page );
+			h.add( next_page );
 			Option.trace( "%s/%s to Popup open JSON", next_page.getID(), next_page.getUniqueKey() );
-			return new PostBack[] { new PostBack( new Open( out[1], false ) ) };
+			try {
+				h.lock();
+				return new PostBack[] { new PostBack( new Open( out[1], false ) ) };
+			}
+			finally{
+				h.unlock();
+			}
 		}
 		if ( p.active_page.getPopupType() != Popup.Type.MODELESS )	return new PostBack[0];
 		try {
-			Page[]	page = data.hist.get( next_key ).getBrowsingPage();
+			Page[]	page = h.getBrowsingPage();
 			for ( int i = 0; i < page.length; i++ ) {
 				if ( page[i].getPopupType() == Popup.Type.MODAL ) {
 					Option.trace( "%s/%s to Popup active cancel, because MODAL opened", next_page.getID(), next_page.getUniqueKey() );
 					return new PostBack[0];
 				}
 			}
+			Option.trace( "%s/%s to Popup active JSON", next_page.getID(), next_page.getUniqueKey() );
+			return new PostBack[] { new PostBack( new Open( p.active_page, true ) ) };
 		}
 		finally {
-			data.hist.get( next_key ).unlock();
+			h.unlock();
 		}
-		Option.trace( "%s/%s to Popup active JSON", next_page.getID(), next_page.getUniqueKey() );
-		return new PostBack[] { new PostBack( new Open( p.active_page, true ) ) };
 	}
 }
 
@@ -138,7 +153,13 @@ class ScriptOutput extends OutputCall {
 	void call() throws Throwable {}
 	PostBack[] make() throws Exception {
 		JavaScript	js = (JavaScript)forward;
-		Option.trace( "%s to JavaScript JSON", js.cmd );
+		StringBuilder	buf = new StringBuilder();
+		for ( int i = 0; i < js.cmd.length; i++ ){
+			buf = buf.append( js.cmd[i] );
+			buf = buf.append( " / " );
+		}
+		buf = buf.append( " to JavaScript JSON" );
+		Option.trace( buf.toString() );
 		return new PostBack[] { new PostBack( new Exec( js.cmd ) ) };
 	}
 }
