@@ -28,27 +28,18 @@ public class Anchor extends Tag {
 	}
 
 	public void write( PrintWriter w, StringMode mode ) {
+		StringBuilder	buf = new StringBuilder( "function(ev){" );
+		buf = buf.append( "if(!paraselene_agency_a(paraselene_get_id('" );
+		buf = buf.append( makeID() );
+		buf = buf.append( "'),'" );
+		buf = buf.append( getAssignedPage().getUniqueKey() );
+		buf = buf.append( "'))paraselene_kill_event(ev);}" );
+		setAnonymousEventHandler( "click", buf.toString() );
 		//setHTTPAjaxHandler( "href", "onclick", "return paraselene_agency_a(this,'%s');" );
-		makeID();
+		//makeID();
 		super.write( w, mode );
-		setHttpAjaxEventListener( w, mode, "paraselene_a_handler(%s,%s)" );
+		//setHttpAjaxEventListener( w, mode, "paraselene_a_handler(%s,%s)" );
 
-/*
-		Page	page = getAssignedPage();
-		String	id = getIDAttribute();
-		if ( page.isAjax() && isAjaxEnable() && id != null ) {
-			Attribute	attr = getAttribute( "href" );
-			if ( attr != null && getAttribute( "target" ) == null && getAttribute( "onclick" ) == null ) {
-				URIValue	v = (URIValue)attr.get();
-				if ( v != null ) {
-					if ( v.isParaselenePagePath() ) {
-						String	cmd = String.format( "paraselene_a_handler('%s','%s');", id, page.getUniqueKey() );
-						page.addOnLoadScript( w, cmd );
-					}
-				}
-			}
-		}
-*/
 	}
 }
 
