@@ -77,18 +77,15 @@ public class Button extends Input {
 	}
 
 	public void write( PrintWriter w, StringMode mode ) {
+		StringBuilder	buf = new StringBuilder( "function(ev){" );
+		buf = buf.append( "paraselene_form_kill=" );
+		buf = buf.append( isAjaxEnable()?	"false":	"true" );
+		buf = buf.append( ";}" );
+		setAnonymousEventHandler( "click", buf.toString() );
 		//setButtonAjaxHandler( "onclick", "return paraselene_button_select(%s);", isAjaxEnable()?	"false":	"true" );
-		makeID();
+		//makeID();
 		super.write( w, mode );
-		setButtonAjaxEventListener( w, mode, "paraselene_button_handler(%s,%s)", isAjaxEnable()?	"false":    "true" );
-/*
-		Page	page = getAssignedPage();
-		String	id = getIDAttribute();
-		if ( page.isAjax() && id != null ) {
-			String	cmd = String.format( "paraselene_button_handler('%s',%s);", id, isAjaxEnable()?	"false":	"true" );
-			page.addOnLoadScript( w, cmd );
-		}
-*/
+		//setButtonAjaxEventListener( w, mode, "paraselene_button_handler(%s,%s)", isAjaxEnable()?	"false":    "true" );
 	}
 }
 
