@@ -49,7 +49,6 @@ public class Table extends Tag {
 			int	cnt = line[i].getColumnRowCount();
 			if ( cnt > xsize )	xsize = cnt;
 		}
-		line = getLineArray();
 		map = new Column[line.length][];
 		for ( int i = 0; i < line.length; i++ ) {
 			map[i] = new Column[xsize];
@@ -79,7 +78,9 @@ public class Table extends Tag {
 		map_y = line.length;
 		for ( int i = 0; i < map_y; i++ ) {
 			for ( int j = 0; j < map_x; j++ ) {
-				if ( map[i][j] == null )	throw new TableException( "不正な行あり" );
+				if ( map[i][j] == null ) {
+					throw new TableException( String.format( "不正な行あり[%d,%d]=null", j, i ) );
+				}
 			}
 		}
 	}
@@ -203,7 +204,7 @@ public class Table extends Tag {
 	 * 列番号、行番号はカラムの連結状態に関係なく、連結されていない場合の番号を
 	 * 指定して下さい。内部で自動判断して、然るべきインスタンスで処理します。<br>
 	 * 連結された先のColumnインスタンスは消滅します。そのタグ内のデータも失われます。
-	 * <br>
+	 * 連結先が既に他のカラムと連結されている場合は、それを解除して連結します。<br>
 	 * 連結解除され、空きができた場所には、新規Columnインスタンスが生成されます。
 	 * そのインスタンスは属性等は持っていません。
 	 * 右寄せ等の必要があれば別途指定する必要があります。
@@ -217,16 +218,19 @@ public class Table extends Tag {
 	 * x y の指定が範囲を超えている。
 	 */
 	public void joinColumn( int x, int y, int xsize, int ysize ) throws TableException {
-		if ( xsize < 0 )	xsize = 1;
-		if ( ysize < 0 )	ysize = 1;
+		makeMap();
+		if ( xsize < 1 )	xsize = 1;
+		if ( ysize < 1 )	ysize = 1;
 		int	max_xsize = map_x - x;
+		int	max_ysize = map_y - y;
 		if ( xsize > max_xsize )	xsize = max_xsize;
-		if ( xsize == 1 && ysize == 1 )	return;
+		if ( ysize > max_ysize )	ysize = max_ysize;
 		Column	clm = getColumn( x, y );
+		if ( xsize == clm.getColspan() && ysize == clm.getRowspan() )	return;
 		boolean	flag = false;
 		for ( int chk_y = 0; chk_y < map_y; chk_y++ ) {
 			for ( int chk_x = 0; chk_x < map_x; chk_x++ ) {
-				if ( map[y][x] == clm ) {
+				if ( map[chk_y][chk_x] == clm ) {
 					x = chk_x;
 					y = chk_y;
 					flag = true;
@@ -235,35 +239,39 @@ public class Table extends Tag {
 			}
 			if ( flag )	break;
 		}
+		clm = getColumn( x, y );
 		int	org_x = clm.getColspan();
 		clm.setColspan( xsize );
 		int	org_y = clm.getRowspan();
 		clm.setRowspan( ysize );
 		int	all_x = org_x, all_y = org_y;
 		if ( all_x < xsize )	all_x = xsize;
+		all_x += x;
 		if ( all_y < ysize )	all_y = ysize;
-		for ( int ycnt = all_y - 1; ycnt >= 0; ycnt-- ) {
-			for ( int xcnt = 0; xcnt < all_x; xcnt++ ) {
-				if ( ycnt == 0 && xcnt == 0 )	continue;
-				Line[]	l = getLineArray();
-				if ( ycnt >= org_y || xcnt >= org_x ) {
-					if ( l.length <= (y + ycnt) )	break;
-					if ( map[y + ycnt][x + xcnt] == clm )	continue;
-					l[y + ycnt].removeColumn( map[y + ycnt][x + xcnt] );
-					map[y + ycnt][x + xcnt] = clm;
-					continue;
+		all_y += y;
+		int	xx = x + xsize - 1, yy = y + ysize - 1;
+		Line[]	l = getLineArray();
+		for ( int ycnt = y; ycnt < all_y; ycnt++ ) {
+			for ( int xcnt = x; xcnt < all_x; xcnt++ ) {
+				if ( ( ycnt > yy && map[ycnt][xcnt] == clm ) ||
+					( xcnt > xx && map[ycnt][xcnt] == clm ) ) {
+					map[ycnt][xcnt] = new Column( clm.getType() );
+					int	idx = 0;
+					for ( int tmp = 0; tmp < xcnt; tmp++ ) {
+						if ( !isJoinedColumn( tmp, ycnt ) )	idx++;
+					}
+					l[ycnt].addColumn( idx, map[ycnt][xcnt] );
+					tabe_dirty_f = false;
 				}
-				if ( map[y + ycnt][x + xcnt] != clm )	continue;
-				if ( l.length <= (y + ycnt) ) {
-					clm.setRowspan( clm.getRowspan() - 1 );
-					break;
+				else if ( ( ycnt <= yy && map[ycnt][xcnt] != clm ) ||
+					( xcnt <= xx && map[ycnt][xcnt] != clm ) ) {
+					if ( map[ycnt][xcnt].getColspan() > 1 || map[ycnt][xcnt].getRowspan() > 1 ) {
+						joinColumn( xcnt, ycnt, 1, 1 );
+					}
+					l[ycnt].removeColumn( map[ycnt][xcnt] );
+					tabe_dirty_f = false;
+					map[ycnt][xcnt] = clm;
 				}
-				int	idx = 0;
-				if ( x > 0 ) {
-					idx = l[y + ycnt].indexOfColumn( map[y + ycnt][x - 1] ) + 1;
-				}
-				map[y + ycnt][x + xcnt] = new Column( clm.getType() );
-				l[y + ycnt].addColumn( idx, map[y + ycnt][x + xcnt] );
 			}
 		}
 	}
